﻿using Microsoft.AspNetCore.Identity;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using System.ComponentModel.DataAnnotations;

namespace DamageAssesment.Api.Documents.Db
{
    public class DocumentDbContext : DbContext
    {
        private IConfiguration _Configuration { get; set; }
        public DocumentDbContext(DbContextOptions options, IConfiguration configuration) : base(options)
        {
            _Configuration = configuration;
        }
        protected override void OnConfiguring(DbContextOptionsBuilder options)
        {
            // connect to sql server with connection string from app settings
            options.UseSqlServer(_Configuration.GetConnectionString("DocumentConnection"));
        }
        public DbSet<Db.Document> Documents { get; set; }
        public DbSet<Db.LinkType> LinkTypes { get; set; }
        public DbSet<Db.DocumentsTranslation> DocumentsTranslations { get; set; }
        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            base.OnModelCreating(modelBuilder);
            modelBuilder.Entity<Document>()
                .Property(item => item.Id)
                .ValueGeneratedOnAdd();
            modelBuilder.Entity<LinkType>()
                .Property(item => item.Id)
                .ValueGeneratedOnAdd();
            modelBuilder.Entity<DocumentsTranslation>()
                .Property(item => item.Id)
                .ValueGeneratedOnAdd();
        }
    }
}
